California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
SENATE DISTRICTS
STATE SENATE 33
GONZALEZ, LENA GUERRERO, JACK M.